@@ -1,15 +1,13 @@
 import argparse
 import asyncio
 import logging
-import os
 import pprint
 import random
 
 from qiskit import QuantumCircuit, execute
 
-from qctic.api import QCticAPI
-from qctic.backend import (QCticQasmSimulator, QCticStatevectorSimulator,
-                           QCticUnitarySimulator)
+from qctic.backend import (QCticAerSimulator, QCticQasmSimulator,
+                           QCticStatevectorSimulator, QCticUnitarySimulator)
 from qctic.provider import QCticProvider
 from qctic.utils import wait_result_async
 
@@ -28,7 +26,6 @@ def init_logging():
         logging.basicConfig()
 
 
-# pylint: disable=no-member
 def random_circuit(max_qubits, unitary=False):
     max_qubits = max_qubits if max_qubits >= _MIN_QUBITS else _MIN_QUBITS
     qubits = random.randint(_MIN_QUBITS, max_qubits)
@@ -69,12 +66,17 @@ def build_result_msg_statevector(result, circuit):
 
 def log_result(result, circuits, backend_name):
     msg_funcs = {
-        QCticQasmSimulator.NAME: build_result_msg_qasm,
-        QCticUnitarySimulator.NAME: build_result_msg_unitary,
-        QCticStatevectorSimulator.NAME: build_result_msg_statevector
+        QCticAerSimulator: build_result_msg_qasm,
+        QCticQasmSimulator: build_result_msg_qasm,
+        QCticUnitarySimulator: build_result_msg_unitary,
+        QCticStatevectorSimulator: build_result_msg_statevector
     }
 
-    msg_func = msg_funcs[backend_name]
+    backend_cls = next(
+        item[1] for item in QCticProvider.BACKEND_OPTIONS
+        if item[0] == backend_name)
+
+    msg_func = msg_funcs[backend_cls]
 
     for idx, circ in enumerate(circuits):
         _logger.info("Circuit #%s results:\n%s", idx, msg_func(result, circ))
@@ -84,31 +86,31 @@ async def execute_jobs(qubits, backend_name, num_circuits, shots, gpu):
     qctic_provider = QCticProvider.from_env()
     qctic_backend = qctic_provider.get_backend(backend_name)
 
-    is_unitary = backend_name == QCticUnitarySimulator.NAME
+    is_unitary = next((
+        True for item in QCticProvider.BACKEND_OPTIONS
+        if item[0] == backend_name and item[1] is QCticUnitarySimulator), False)
 
     circuits = [
         random_circuit(max_qubits=qubits, unitary=is_unitary)
-        for _idx in range(num_circuits)
+        for _ in range(num_circuits)
     ]
 
     for idx, circ in enumerate(circuits):
         _logger.info("Circuit #%s:\n%s", idx, circ.draw())
 
-    backend_options = {}
+    backend_options = {"device": "GPU" if gpu else "CPU"}
 
-    if gpu and backend_name == QCticQasmSimulator.NAME:
-        backend_options.update({"method": "statevector_gpu"})
-    elif gpu and backend_name != QCticQasmSimulator.NAME:
-        _logger.warning("Ignoring GPU flag")
-
-    memory = backend_name == QCticQasmSimulator.NAME
+    memory = backend_name in [
+        item[0] for item in QCticProvider.BACKEND_OPTIONS
+        if item[1] in (QCticAerSimulator, QCticQasmSimulator)
+    ]
 
     qctic_job = execute(
         circuits,
         qctic_backend,
         shots=shots,
-        backend_options=backend_options,
-        memory=memory)
+        memory=memory,
+        **backend_options)
 
     await qctic_job.submit_task
     result = await wait_result_async(qctic_job)
@@ -131,16 +133,10 @@ def parse_args():
     parser.add_argument("--qubits", type=int, default=4)
     parser.add_argument("--gpu", action="store_true")
 
-    backend_choices = [
-        QCticQasmSimulator.NAME,
-        QCticStatevectorSimulator.NAME,
-        QCticUnitarySimulator.NAME
-    ]
-
     parser.add_argument(
         "--backend",
         default=QCticQasmSimulator.NAME,
-        choices=backend_choices)
+        choices=[item[0] for item in QCticProvider.BACKEND_OPTIONS])
 
     return parser.parse_args()
 
