@@ -1,26 +1,23 @@
 # pylint: disable=no-member
 
-import asyncio
-import datetime
 import json
-import random
 import re
 import uuid
 
 import pytest
-from qiskit import assemble, execute
-from qiskit.providers import JobStatus
-from werkzeug.wrappers import Response
-
 from qctic.api import QCticAPI
 from qctic.job import QCticJob
 from qctic.provider import QCticProvider
-from tests.utils import fake_circuit, fake_job_dict, fake_qobj
+from qiskit import assemble
+from qiskit.providers import JobStatus
+from werkzeug.wrappers import Response
+
+from tests.utils import fake_circuit, fake_job_dict
 
 
 def _random_job(api):
     provider = QCticProvider(api=api)
-    backend = provider.backends()[0]
+    backend = provider.get_backend("aer_simulator")
     qobj = assemble(fake_circuit(), backend)
     job_id = str(uuid.uuid4())
 
